# History

## 0.5.0 (2020-01-10)

* **Breaking** Always return User from UserRepository

## 0.4.1 (2020-01-09)

* Improved API consistency

## 0.4.0 (2020-01-09)

* **Breaking** Split StatusResponse on two classes

## 0.3.0 (2020-01-06)

* **Breaking** Return StatusResponse from each method of repositories

## 0.1.0 (2019-12-31)

* First release on PyPI.
